<table width="600" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="left" class="title"><h2>{% block title %}{% endblock %}</h2></td>
  </tr>
  <tr>
    <td height="10">&nbsp;</td>
  </tr>
  <tr>
    <td align="left" valign="top"><img src="{{NEWSLETTER_URL}}default_image.jpg" width="600" height="600" /></td>
  </tr>
</table>
<br />
<br />
<br />
<br />
<table width="600" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="right"><a href="yoursuperlinkhere.com" class="webViewLink">NEWSLETTER KÜNDIGEN</a></td>
  </tr>
  <tr>
    <td align="right" height="20"></td>
  </tr>
</table>
