<h2>Unsubscribe</h2>
{% if done %}
    you habe been removed from the list
{% else %}
<p>Are you sure you want to unsubscribe this newsletter?</p>
<a href=".?unsubscribe=1">unsubscribe</a>
{% endif %}