  <table width="600" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="left" class="title"><h2>{% block title %}{% endblock %}</h2></td>
  </tr>
  <tr>
    <td height="10">&nbsp;</td>
  </tr>
  <tr>
    <td align="left" valign="top"><table width="600" border="0" cellspacing="0" cellpadding="0">
      <tr>
        <td width="135"><img src="{{NEWSLETTER_URL}}default_image.jpg" width="135" height="157" /></td>
        <td width="20" rowspan="2">&nbsp;</td>
        <td width="135"><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td width="20" rowspan="2">&nbsp;</td>
        <td width="135"><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td width="20" rowspan="2">&nbsp;</td>
        <td width="135"><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        </tr>
      <tr>
        <td>Legende</td>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        </tr>
      <tr>
        <td height="20" colspan="7">&nbsp;</td>
        </tr>
      <tr>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        </tr>
      <tr>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        </tr>
      <tr>
        <td height="20" colspan="7">&nbsp;</td>
        </tr>
      <tr>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        </tr>
      <tr>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        </tr>
      <tr>
        <td height="20" colspan="7">&nbsp;</td>
        </tr>
      <tr>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        <td rowspan="2">&nbsp;</td>
        <td><img src="{{NEWSLETTER_URL}}default_image.jpg" alt="" width="135" height="157" /></td>
        </tr>
      <tr>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        <td>Sub</td>
        </tr>
    </table></td>
  </tr>
</table>
<br />
<br />
