{%extends "admin/change_form.html" %}
{% load i18n %}
{% block after_related_objects %}
    {% if can_send %}
        <div class="submit-row">
            <input type="submit" value="Save and send" class="default" name="_send_prepare" />
        </div>
    {% endif %}
    {{block.super}}
{% endblock %}
