{% load feincms_tags i18n pennyblack_tags %}
{% newsletterstyle request text_only_text %}font-size:18px;font-family:times New Roman, serif; color:#000000;text-align:center;{% endnewsletterstyle %}
{% newsletterstyle request text_only_title %}font-size:18px;font-family:times New Roman, serif;font-weight:normal; color:#000000;text-align:center;{% endnewsletterstyle %}
{% newsletterstyle request link_style %}color:#333333;{% endnewsletterstyle %}
{% if webview %}
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>{% block title %}{{newsletter.subject}}{% endblock %}</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">

</head>
{% endif %}
<body bgcolor="#CCCCCC" topmargin="0" leftmargin="0" >
<table width="100%" border="0" cellspacing="0" cellpadding="0">
  <tr>
    <td align="center"><table width="680" border="0" cellspacing="0" cellpadding="0">
        {% if not webview %}
            <tr>
              <td height="20" align="center" bgcolor="#FFFFFF">&nbsp;</td>
            </tr>
            <tr>
              <td align="center" bgcolor="#FFFFFF">
              <table width="630" border="0" cellspacing="0" cellpadding="0">
                <tr>
                  <td align="right">{% trans "To view this email as a web page, click" %} <a href="{{newsletter.get_base_url}}{% url pennyblack.view mail.mail_hash %}">{% trans "here" %}</a></td>
                </tr>
              </table></td>
            </tr>
        {% endif %}
      <tr>
        <td align="center" bgcolor="#FFFFFF" height="60">&nbsp;</td>
      </tr>
      <tr>
        <td align="center">{% header_image alt="Pennyblack" %}</td>
      </tr>
      <tr>
        <td align="center" bgcolor="#FFFFFF" height="26"></td>
      </tr>
      <tr>
        <td align="center" bgcolor="#FFFFFF"><table width="630" border="0" cellspacing="0" cellpadding="0">
          <tr>
            <td align="center" bgcolor="#F4F4F4"><p>&nbsp;</p>
                {# render content #}
                {% feincms_render_region newsletter "main" request %}
            </td>
          </tr>
        </table></td>
      </tr>
      <tr>
        <td align="center"></td>
      </tr>
    </table></td>
  </tr>
</table>
</body>


{% if webview %}
</html>
{% endif %}