{% extends "admin/feincms/item_editor.html" %}

{% load i18n %}

{% block object-tools %}
<ul class="object-tools">
    <li><a href="preview/" target="_blank">{% trans "preview"|capfirst %}</a></li>
    <li><a href="history/" class="historylink">{% trans "History" %}</a></li>
</ul>
{% endblock %}
