# coding=utf-8
from pennyblack.models.newsletter import Newsletter
from pennyblack.models.job import Job
from pennyblack.models.link import Link, LinkClick
from pennyblack.models.mail import Mail
from pennyblack.models.sender import Sender

__all__ = ('Newsletter','Job', 'Link', 'LinkClick', 'Mail', 'Sender')
