{%extends "admin/change_form.html" %}
{% load i18n %}
{% block object-tools %}
{% if change %}{% if not is_popup %}
  <ul class="object-tools"><li><a href="history/" class="historylink">{% trans "History" %}</a></li>
      <li><a href="create_newsletter/">{% trans "Newsletter Erstellen" %}</a></li>
  {% if has_absolute_url %}<li><a href="../../../r/{{ content_type_id }}/{{ object_id }}/" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}  
  {% block object-tools-extra %}{% endblock %}
  </ul>
{% endif %}{% endif %}
{% endblock %}
